#line 2 "parser/lex.de.C"

#line 4 "parser/lex.de.C"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 31
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE derestart(dein  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int deleng;

extern FILE *dein, *deout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up detext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up detext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via derestart()), so that the user can continue scanning by
	 * just pointing dein at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when detext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int deleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 1;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow dewrap()'s to do buffer switches
 * instead of setting up a fresh dein.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void derestart (FILE *input_file  );
void de_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE de_create_buffer (FILE *file,int size  );
void de_delete_buffer (YY_BUFFER_STATE b  );
void de_flush_buffer (YY_BUFFER_STATE b  );
void depush_buffer_state (YY_BUFFER_STATE new_buffer  );
void depop_buffer_state (void );

static void deensure_buffer_stack (void );
static void de_load_buffer_state (void );
static void de_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER de_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE de_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE de_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE de_scan_bytes (yyconst char *bytes,int len  );

void *dealloc (yy_size_t  );
void *derealloc (void *,yy_size_t  );
void defree (void *  );

#define yy_new_buffer de_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        deensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            de_create_buffer(dein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        deensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            de_create_buffer(dein,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define dewrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *dein = (FILE *) 0, *deout = (FILE *) 0;

typedef int yy_state_type;

extern int delineno;

int delineno = 1;

extern char *detext;
#define yytext_ptr detext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up detext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	deleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 161
#define YY_END_OF_BUFFER 162
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[502] =
    {   0,
        0,    0,    0,    0,    2,    2,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  162,  160,   39,   40,  158,  142,  158,  158,
      129,  158,  158,  112,  113,  157,  158,  158,  158,  160,
      123,  158,  160,  158,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  158,   43,    1,    2,    3,    4,   20,    7,
       21,   19,   20,   18,   18,   18,   18,   18,   18,   22,

       23,   29,    7,   28,   27,   29,   25,   26,   30,    7,
       30,   31,    7,   31,   34,    7,   33,   32,   34,   35,
        7,   35,   38,    7,   37,   38,   36,  122,  119,  121,
      116,  117,  118,  120,  128,  127,  128,  135,  136,  130,
      135,  141,  137,  138,  140,  139,  150,  149,  143,  151,
      156,  152,  153,  155,  154,   39,   76,   71,   74,   41,
       42,  111,   79,   78,   72,   75,   67,   77,   80,  112,
      114,    0,  123,   73,  124,  159,   68,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,

      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,   70,    2,    3,    4,    5,
        4,    6,    7,    9,    8,   18,   18,   18,   18,   18,
       18,   18,   18,   22,   24,   36,  127,  126,  125,  134,
      131,  132,  134,  150,  148,  144,  145,  147,   42,   69,
      115,  123,  123,  123,   91,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  103,  123,  123,  123,
       57,  123,   45,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,    8,

       18,   18,   18,   18,   18,   18,   18,   18,  125,  131,
      133,  144,  146,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  107,  123,   54,   66,   65,  123,  123,   58,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  123,  123,  123,   18,
       12,   18,   18,   18,   18,   11,   18,   52,  123,  123,
      123,  123,  123,   95,  123,  123,  123,   97,  110,  123,
      123,  123,   59,  123,  106,   98,  123,   83,  123,  123,
       88,  123,  102,  123,  123,  100,  123,  123,  123,  123,

      101,  123,  105,  123,   60,  123,  123,  123,  123,  123,
       18,   13,   14,   18,   18,   17,  123,  123,  123,  123,
       86,  123,   53,  123,   61,   63,  123,   82,  123,   51,
       81,   55,  123,  123,  104,  123,  123,  123,  123,   56,
      123,  123,  123,   44,   46,  123,   16,   15,   18,  123,
      123,  123,  123,  123,   50,  123,  123,  109,  123,   87,
       99,   48,  123,  123,  123,   84,   94,   10,   85,  123,
      123,  123,  123,  123,  123,   47,  123,  123,  123,  123,
      123,  123,  123,  108,  123,   89,  123,  123,  123,  123,
      123,   96,   49,  123,   62,  123,   93,   90,   92,   64,

        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    7,    8,    9,   10,
       11,   12,    7,    7,    7,    7,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,    7,   17,   18,
       19,   20,    7,   21,   22,   22,   22,   22,   22,   22,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       24,   25,   26,   27,   23,    1,   28,   29,   30,   31,

       32,   33,   34,   35,   36,   23,   23,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   23,    7,   51,    7,    7,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[52] =
    {   0,
        1,    1,    2,    1,    3,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    5,    5,    1,    1,    1,    1,
        1,    5,    6,    1,    3,    1,    1,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        1
    } ;

static yyconst flex_int16_t yy_base[530] =
    {   0,
        0,  841,    0,    0,   49,   50,   62,    0,  843,  842,
      112,  116,  120,  121,  122,  134,  135,  139,  137,  141,
      154,    0,  205,    0,  243,  263,   40,   43,  296,    0,
      257,  258,  131,  248,  334,  354,  265,  348,  266,  272,
      374,  394,  844, 3348,  841, 3348,  823, 3348, 3348,  833,
     3348,  829,  276,  790, 3348, 3348,  339,  335,  341,  377,
        0,  812,  832,  806,  787,  783,  389,  348,  390,  349,
      371,   84,  225,  109,  402,  779,  403,  792,  398,  409,
      770,  772,  756, 3348, 3348,  803, 3348,  444, 3348,  803,
     3348, 3348,  359,    0,  772,  342,  379,  767,  763,    0,

     3348, 3348,  799, 3348, 3348,  362,  751, 3348, 3348,  797,
      388, 3348,  796,  422, 3348,  795, 3348, 3348,  436, 3348,
      794,  438, 3348,  793, 3348,  441,    0, 3348, 3348, 3348,
     3348, 3348, 3348, 3348, 3348,    0,  791, 3348, 3348, 3348,
      452, 3348, 3348, 3348, 3348, 3348,    0, 3348, 3348,  455,
     3348, 3348, 3348, 3348, 3348,  791, 3348, 3348, 3348, 3348,
        0, 3348, 3348,  772, 3348, 3348, 3348, 3348, 3348,  742,
     3348,  445,    0, 3348, 3348, 3348, 3348,  750,  757,  745,
      504,  749,  743,  744,  740,  729,  746,  737,  376,  719,
      712,  555,  728,  718,  723,  606,  657,  719,  707,  422,

      712,  719,  704,  703,  719,  432,  709,  705,  434,  444,
      701,  705,  369,  445,  698, 3348,  738, 3348,  472, 3348,
      476, 3348,  738, 3348,    0,    0,  706,  694,  706,  452,
      706,  694,  700,    0, 3348,    0,    0, 3348,  728, 3348,
      722, 3348,    0,    0, 3348,  721, 3348,    0,    0, 3348,
     3348,  684,  679,  675, 3348,  664,  659,  662,  657,  673,
      663,  654,  654,  669,  666,  663, 3348,  653,  652,  660,
     3348,  659, 3348,  708,  646,  759,  810,  861,  657,  912,
      653,  657,  655,  647,  650,  632,  634,  633,  443,  642,
      633,  624,  616,  622,  621,  612,  610,  613,  602,    0,

      611,  614,  609,  612,  612,  605,  609,  608,  637,  636,
     3348,  635, 3348,  963,  605,  599,  456,  599, 1014,  581,
      592, 1065, 1116,  596,  585,  576, 1167,  585, 1218, 1269,
      562, 3348, 1320, 3348, 3348, 3348,  560,  566, 3348, 1371,
      570, 1422,  560,  572, 1473,  555,  559,  565,  564, 1524,
      559, 1575,  550, 1626,  560,  555,  552,  553,  561,  549,
        0,  554,  553,  553,  538,    0,  550, 3348,  535,  539,
      540,  532, 1677, 3348,  527, 1728,  525, 3348, 3348, 1779,
     1830,  518, 3348, 1881, 3348, 3348,  509, 3348, 1932, 1983,
     3348, 2034, 3348,  507,  507, 3348, 2085,  516,  504,  503,

     3348,  508, 3348, 2136, 3348,  510,  514, 2187, 2238,  507,
      511,    0,    0,  509,  510,    0,  505,  511,  506,  505,
     3348,  508, 3348, 2289, 3348, 3348,  495, 3348,  502, 3348,
     3348, 3348, 2340,  501, 3348, 2391, 2442, 2493,  504, 3348,
      501,  488, 2544, 3348, 3348, 2595,    0,    0,  494, 2646,
      483,  488,  479,  462, 3348,  463,  470, 3348, 2697, 3348,
     3348, 3348,  462,  453,  465, 3348, 3348,    0, 3348,  459,
      458,  448,  451, 2748,  435, 3348, 2799,  428,  434,  391,
      376,  334, 2850, 3348, 2901, 3348,  309, 2952,  234, 3003,
     3054, 3348, 3348, 3105, 3348, 3156, 3348, 3348, 3348, 3348,

     3348, 3207, 3213, 3219, 3225, 3231, 3237, 3243, 3249, 3255,
     3261, 3267, 3273, 3275, 3281, 3287, 3293, 3295, 3301, 3303,
     3305, 3311, 3317, 3323, 3329, 3335, 3341,  146,   55
    } ;

static yyconst flex_int16_t yy_def[530] =
    {   0,
      501,    1,  502,  502,  503,  503,  501,    7,  504,  504,
      505,  505,  506,  506,  507,  507,  508,  508,  509,  509,
      501,   21,  501,   23,   23,   23,   23,   23,  501,   29,
      510,  510,  511,  511,  511,  511,  512,  512,  513,  513,
      513,  513,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      514,  501,  515,  501,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  501,  501,  501,  516,  501,  517,  501,  501,
      501,  501,  501,  518,  518,  518,  518,  518,  518,  519,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  520,  501,  501,  501,
      501,  501,  501,  501,  501,  521,  522,  501,  501,  501,
      523,  501,  501,  501,  501,  501,  524,  501,  501,  525,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      526,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  514,  501,  501,  501,  501,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,

      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  501,  516,  501,  517,  501,
      517,  501,  501,  501,  527,  518,  518,  518,  518,  518,
      518,  518,  518,  519,  501,  520,  521,  501,  501,  501,
      501,  501,  528,  524,  501,  501,  501,  529,  526,  501,
      501,  514,  514,  514,  501,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  501,  514,  514,  514,
      501,  514,  501,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  527,

      518,  518,  518,  518,  518,  518,  518,  518,  501,  501,
      501,  501,  501,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  501,  514,  501,  501,  501,  514,  514,  501,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  514,
      514,  514,  514,  514,  514,  514,  514,  514,  514,  518,
      518,  518,  518,  518,  518,  518,  518,  501,  514,  514,
      514,  514,  514,  501,  514,  514,  514,  501,  501,  514,
      514,  514,  501,  514,  501,  501,  514,  501,  514,  514,
      501,  514,  501,  514,  514,  501,  514,  514,  514,  514,

      501,  514,  501,  514,  501,  514,  514,  514,  514,  514,
      518,  518,  518,  518,  518,  518,  514,  514,  514,  514,
      501,  514,  501,  514,  501,  501,  514,  501,  514,  501,
      501,  501,  514,  514,  501,  514,  514,  514,  514,  501,
      514,  514,  514,  501,  501,  514,  518,  518,  518,  514,
      514,  514,  514,  514,  501,  514,  514,  501,  514,  501,
      501,  501,  514,  514,  514,  501,  501,  518,  501,  514,
      514,  514,  514,  514,  514,  501,  514,  514,  514,  514,
      514,  514,  514,  501,  514,  501,  514,  514,  514,  514,
      514,  501,  501,  514,  501,  514,  501,  501,  501,  501,

        0,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501
    } ;

static yyconst flex_int16_t yy_nxt[3400] =
    {   0,
       44,   45,   46,   47,   48,   49,   49,   50,   51,   52,
       49,   49,   53,   54,   55,   55,   56,   57,   58,   59,
       60,   61,   61,   62,   63,   49,   64,   65,   66,   67,
       68,   69,   70,   71,   72,   73,   74,   75,   61,   76,
       77,   61,   78,   79,   80,   81,   82,   61,   61,   61,
       83,   87,   87,  134,  134,  134,  134,  134,  134,  313,
       88,   88,   89,   90,   91,   92,   89,   89,   89,   89,
       89,   89,   89,   89,   93,   89,   89,   89,   89,   89,
       89,   89,   89,   94,   94,   89,   89,   89,   89,   94,
       94,   94,   95,   96,   94,   94,   94,   97,   98,   94,

       94,   94,   94,   94,   94,   94,   94,   99,   94,   94,
       94,   94,   89,  103,  104,  194,  105,  103,  104,  195,
      105,  110,  110,  113,  106,  107,  108,  108,  106,  107,
      108,  108,  111,  111,  114,  113,  116,  117,  121,  118,
      116,  117,  121,  118,  143,  143,  114,  119,  198,  122,
      311,  119,  199,  122,  123,  124,  125,  123,  123,  123,
      123,  123,  123,  123,  123,  123,  126,  123,  123,  123,
      123,  123,  123,  123,  123,  127,  127,  123,  123,  123,
      123,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,

      127,  127,  127,  127,  123,  128,  128,  128,  128,  128,
      128,  128,  128,  128,  128,  128,  128,  128,  129,  129,
      130,  128,  128,  128,  128,  128,  130,  130,  128,  128,
      128,  128,  130,  130,  130,  130,  130,  130,  130,  130,
      130,  130,  130,  130,  130,  130,  130,  130,  130,  130,
      130,  130,  130,  130,  130,  128,  131,  131,  131,  139,
      139,  143,  143,  196,  132,  140,  140,  148,  197,  149,
      133,  133,  133,  133,  133,  133,  131,  131,  131,  152,
      152,  141,  141,  496,  132,  152,  152,  160,  161,  150,
      133,  133,  133,  133,  133,  133,  135,  135,  135,  135,

      135,  135,  135,  135,  135,  135,  135,  135,  135,  136,
      136,  136,  135,  135,  135,  135,  135,  136,  136,  135,
      137,  135,  135,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  136,  136,  136,  136,
      136,  136,  136,  136,  136,  136,  135,  144,  144,  144,
      148,  494,  149,  166,  167,  145,  163,  164,  165,  168,
      169,  146,  146,  146,  146,  146,  146,  144,  144,  144,
      224,  225,  150,  224,  225,  145,  189,  491,  228,  183,
      229,  146,  146,  146,  146,  146,  146,  153,  153,  153,
      170,  171,  171,  184,  190,  154,  293,  172,  191,  224,

      225,  155,  155,  155,  155,  155,  155,  153,  153,  153,
      192,  230,  263,  193,  294,  154,  180,  231,  490,  181,
      264,  155,  155,  155,  155,  155,  155,  185,  182,  200,
      204,  186,  208,  224,  225,  489,  187,  201,  188,  205,
      211,  202,  209,  210,  212,  206,  220,  224,  225,  224,
      225,  213,  224,  225,  241,  221,  222,  246,  170,  251,
      251,  287,  276,  283,  488,  242,  242,  487,  247,  247,
      277,  284,  289,  290,  220,  295,  288,  296,  220,  485,
      297,  348,  304,  501,  501,  483,  349,  221,  222,  298,
      305,  371,  482,  481,  480,  372,  479,  478,  477,  475,

      243,  474,  473,  248,  255,  255,  255,  255,  255,  255,
      255,  255,  255,  255,  255,  255,  255,  472,  471,  470,
      255,  255,  255,  255,  255,  468,  465,  255,  464,  255,
      255,  463,  459,  457,  456,  454,  453,  452,  451,  450,
      449,  448,  447,  446,  443,  442,  439,  438,  437,  436,
      434,  433,  429,  427,  255,  267,  267,  267,  267,  267,
      267,  267,  267,  267,  267,  267,  267,  267,  424,  422,
      420,  267,  267,  267,  267,  267,  419,  418,  267,  417,
      267,  267,  416,  415,  414,  413,  412,  411,  410,  409,
      408,  407,  406,  404,  402,  400,  399,  398,  397,  395,

      394,  392,  390,  389,  387,  267,  271,  271,  271,  271,
      271,  271,  271,  271,  271,  271,  271,  271,  271,  384,
      382,  381,  271,  271,  271,  271,  271,  380,  377,  271,
      376,  271,  271,  373,  370,  369,  312,  310,  309,  367,
      366,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      272,  356,  355,  354,  353,  352,  271,  273,  273,  273,
      273,  273,  273,  273,  273,  273,  273,  273,  273,  273,
      351,  350,  347,  273,  273,  273,  273,  273,  346,  345,
      273,  344,  273,  273,  343,  342,  341,  340,  338,  333,
      331,  330,  329,  328,  327,  326,  325,  324,  323,  322,

      321,  320,  319,  318,  317,  316,  315,  273,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  314,  312,  310,  332,  332,  332,  332,  332,  309,
      308,  332,  307,  332,  332,  306,  303,  302,  301,  223,
      218,  299,  292,  291,  286,  285,  282,  281,  280,  279,
      278,  275,  274,  270,  269,  268,  266,  265,  332,  334,
      334,  334,  334,  334,  334,  334,  334,  334,  334,  334,
      334,  334,  262,  261,  260,  334,  334,  334,  334,  334,
      259,  258,  334,  257,  334,  334,  256,  254,  253,  252,
      162,  250,  156,  239,  223,  223,  223,  223,  223,  235,

      223,  233,  232,  227,  223,  218,  216,  215,  214,  334,
      335,  335,  335,  335,  335,  335,  335,  335,  335,  335,
      335,  335,  335,  207,  203,  179,  335,  335,  335,  335,
      335,  178,  177,  335,  176,  335,  335,  174,  162,  159,
      158,  157,  156,  501,  101,  101,   84,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      335,  336,  336,  336,  336,  336,  336,  336,  336,  336,
      336,  336,  336,  336,  501,  501,  501,  336,  336,  336,
      336,  336,  501,  501,  336,  501,  336,  336,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  337,  501,  501,  501,
      501,  336,  339,  339,  339,  339,  339,  339,  339,  339,
      339,  339,  339,  339,  339,  501,  501,  501,  339,  339,
      339,  339,  339,  501,  501,  339,  501,  339,  339,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  339,  368,  368,  368,  368,  368,  368,  368,
      368,  368,  368,  368,  368,  368,  501,  501,  501,  368,
      368,  368,  368,  368,  501,  501,  368,  501,  368,  368,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  368,  374,  374,  374,  374,  374,  374,
      374,  374,  374,  374,  374,  374,  374,  501,  501,  501,
      374,  374,  374,  374,  374,  501,  501,  374,  501,  374,
      374,  501,  501,  501,  501,  501,  501,  375,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  374,  378,  378,  378,  378,  378,
      378,  378,  378,  378,  378,  378,  378,  378,  501,  501,
      501,  378,  378,  378,  378,  378,  501,  501,  378,  501,
      378,  378,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  378,  379,  379,  379,  379,
      379,  379,  379,  379,  379,  379,  379,  379,  379,  501,
      501,  501,  379,  379,  379,  379,  379,  501,  501,  379,
      501,  379,  379,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  379,  383,  383,  383,
      383,  383,  383,  383,  383,  383,  383,  383,  383,  383,
      501,  501,  501,  383,  383,  383,  383,  383,  501,  501,
      383,  501,  383,  383,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  383,  385,  385,
      385,  385,  385,  385,  385,  385,  385,  385,  385,  385,
      385,  501,  501,  501,  385,  385,  385,  385,  385,  501,
      501,  385,  501,  385,  385,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  385,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  501,  501,  501,  386,  386,  386,  386,  386,
      501,  501,  386,  501,  386,  386,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  386,
      388,  388,  388,  388,  388,  388,  388,  388,  388,  388,
      388,  388,  388,  501,  501,  501,  388,  388,  388,  388,
      388,  501,  501,  388,  501,  388,  388,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      388,  391,  391,  391,  391,  391,  391,  391,  391,  391,
      391,  391,  391,  391,  501,  501,  501,  391,  391,  391,
      391,  391,  501,  501,  391,  501,  391,  391,  501,  501,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  391,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  501,  501,  501,  393,  393,
      393,  393,  393,  501,  501,  393,  501,  393,  393,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  393,  396,  396,  396,  396,  396,  396,  396,
      396,  396,  396,  396,  396,  396,  501,  501,  501,  396,
      396,  396,  396,  396,  501,  501,  396,  501,  396,  396,

      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  396,  401,  401,  401,  401,  401,  401,
      401,  401,  401,  401,  401,  401,  401,  501,  501,  501,
      401,  401,  401,  401,  401,  501,  501,  401,  501,  401,
      401,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  401,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  501,  501,
      501,  403,  403,  403,  403,  403,  501,  501,  403,  501,

      403,  403,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  403,  405,  405,  405,  405,
      405,  405,  405,  405,  405,  405,  405,  405,  405,  501,
      501,  501,  405,  405,  405,  405,  405,  501,  501,  405,
      501,  405,  405,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  405,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      501,  501,  501,  421,  421,  421,  421,  421,  501,  501,

      421,  501,  421,  421,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  421,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  501,  501,  501,  423,  423,  423,  423,  423,  501,
      501,  423,  501,  423,  423,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  423,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  425,  425,
      425,  425,  501,  501,  501,  425,  425,  425,  425,  425,

      501,  501,  425,  501,  425,  425,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  425,
      426,  426,  426,  426,  426,  426,  426,  426,  426,  426,
      426,  426,  426,  501,  501,  501,  426,  426,  426,  426,
      426,  501,  501,  426,  501,  426,  426,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      426,  428,  428,  428,  428,  428,  428,  428,  428,  428,
      428,  428,  428,  428,  501,  501,  501,  428,  428,  428,

      428,  428,  501,  501,  428,  501,  428,  428,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  428,  430,  430,  430,  430,  430,  430,  430,  430,
      430,  430,  430,  430,  430,  501,  501,  501,  430,  430,
      430,  430,  430,  501,  501,  430,  501,  430,  430,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  430,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  501,  501,  501,  431,

      431,  431,  431,  431,  501,  501,  431,  501,  431,  431,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  431,  432,  432,  432,  432,  432,  432,
      432,  432,  432,  432,  432,  432,  432,  501,  501,  501,
      432,  432,  432,  432,  432,  501,  501,  432,  501,  432,
      432,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  432,  435,  435,  435,  435,  435,
      435,  435,  435,  435,  435,  435,  435,  435,  501,  501,

      501,  435,  435,  435,  435,  435,  501,  501,  435,  501,
      435,  435,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  435,  440,  440,  440,  440,
      440,  440,  440,  440,  440,  440,  440,  440,  440,  501,
      501,  501,  440,  440,  440,  440,  440,  501,  501,  440,
      501,  440,  440,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  441,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  440,  444,  444,  444,
      444,  444,  444,  444,  444,  444,  444,  444,  444,  444,

      501,  501,  501,  444,  444,  444,  444,  444,  501,  501,
      444,  501,  444,  444,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  444,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  501,  501,  501,  445,  445,  445,  445,  445,  501,
      501,  445,  501,  445,  445,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  445,  455,
      455,  455,  455,  455,  455,  455,  455,  455,  455,  455,

      455,  455,  501,  501,  501,  455,  455,  455,  455,  455,
      501,  501,  455,  501,  455,  455,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  455,
      458,  458,  458,  458,  458,  458,  458,  458,  458,  458,
      458,  458,  458,  501,  501,  501,  458,  458,  458,  458,
      458,  501,  501,  458,  501,  458,  458,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      458,  460,  460,  460,  460,  460,  460,  460,  460,  460,

      460,  460,  460,  460,  501,  501,  501,  460,  460,  460,
      460,  460,  501,  501,  460,  501,  460,  460,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  460,  461,  461,  461,  461,  461,  461,  461,  461,
      461,  461,  461,  461,  461,  501,  501,  501,  461,  461,
      461,  461,  461,  501,  501,  461,  501,  461,  461,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  461,  462,  462,  462,  462,  462,  462,  462,

      462,  462,  462,  462,  462,  462,  501,  501,  501,  462,
      462,  462,  462,  462,  501,  501,  462,  501,  462,  462,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  462,  466,  466,  466,  466,  466,  466,
      466,  466,  466,  466,  466,  466,  466,  501,  501,  501,
      466,  466,  466,  466,  466,  501,  501,  466,  501,  466,
      466,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  466,  467,  467,  467,  467,  467,

      467,  467,  467,  467,  467,  467,  467,  467,  501,  501,
      501,  467,  467,  467,  467,  467,  501,  501,  467,  501,
      467,  467,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  467,  469,  469,  469,  469,
      469,  469,  469,  469,  469,  469,  469,  469,  469,  501,
      501,  501,  469,  469,  469,  469,  469,  501,  501,  469,
      501,  469,  469,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  469,  476,  476,  476,

      476,  476,  476,  476,  476,  476,  476,  476,  476,  476,
      501,  501,  501,  476,  476,  476,  476,  476,  501,  501,
      476,  501,  476,  476,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  476,  484,  484,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  501,  501,  501,  484,  484,  484,  484,  484,  501,
      501,  484,  501,  484,  484,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  484,  486,

      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  501,  501,  501,  486,  486,  486,  486,  486,
      501,  501,  486,  501,  486,  486,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  486,
      492,  492,  492,  492,  492,  492,  492,  492,  492,  492,
      492,  492,  492,  501,  501,  501,  492,  492,  492,  492,
      492,  501,  501,  492,  501,  492,  492,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      492,  493,  493,  493,  493,  493,  493,  493,  493,  493,
      493,  493,  493,  493,  501,  501,  501,  493,  493,  493,
      493,  493,  501,  501,  493,  501,  493,  493,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  493,  495,  495,  495,  495,  495,  495,  495,  495,
      495,  495,  495,  495,  495,  501,  501,  501,  495,  495,
      495,  495,  495,  501,  501,  495,  501,  495,  495,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  495,  497,  497,  497,  497,  497,  497,  497,
      497,  497,  497,  497,  497,  497,  501,  501,  501,  497,
      497,  497,  497,  497,  501,  501,  497,  501,  497,  497,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  497,  498,  498,  498,  498,  498,  498,
      498,  498,  498,  498,  498,  498,  498,  501,  501,  501,
      498,  498,  498,  498,  498,  501,  501,  498,  501,  498,
      498,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  498,  499,  499,  499,  499,  499,
      499,  499,  499,  499,  499,  499,  499,  499,  501,  501,
      501,  499,  499,  499,  499,  499,  501,  501,  499,  501,
      499,  499,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  499,  500,  500,  500,  500,
      500,  500,  500,  500,  500,  500,  500,  500,  500,  501,
      501,  501,  500,  500,  500,  500,  500,  501,  501,  500,
      501,  500,  500,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,

      501,  501,  501,  501,  501,  501,  500,   85,   85,   85,
       85,   85,   85,   86,   86,   86,   86,   86,   86,  100,
      100,  100,  100,  100,  100,  102,  102,  102,  102,  102,
      102,  109,  109,  109,  109,  109,  109,  112,  112,  112,
      112,  112,  112,  115,  115,  115,  115,  115,  115,  120,
      120,  120,  120,  120,  120,  138,  138,  138,  138,  138,
      138,  142,  142,  142,  142,  142,  142,  147,  147,  147,
      147,  147,  147,  151,  151,  151,  151,  151,  151,  173,
      173,  175,  175,  175,  175,  175,  175,  217,  217,  217,
      501,  217,  217,  219,  219,  219,  219,  219,  219,  226,

      226,  234,  501,  234,  234,  234,  234,  236,  236,  237,
      237,  238,  238,  238,  238,  238,  238,  240,  240,  240,
      240,  240,  240,  244,  501,  501,  244,  244,  244,  245,
      245,  245,  245,  245,  245,  249,  501,  249,  249,  249,
      249,  300,  501,  300,  300,  300,  300,   43,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501

    } ;

static yyconst flex_int16_t yy_chk[3400] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,   27,   27,   27,   28,   28,   28,  529,
        5,    6,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,   11,   11,   72,   11,   12,   12,   72,
       12,   13,   14,   15,   11,   11,   11,   11,   12,   12,
       12,   12,   13,   14,   15,   16,   17,   17,   19,   17,
       18,   18,   20,   18,   33,   33,   16,   17,   74,   19,
      528,   18,   74,   20,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,

       21,   21,   21,   21,   21,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   25,   25,   25,   31,
       32,   34,   34,   73,   25,   31,   32,   37,   73,   37,
       25,   25,   25,   25,   25,   25,   26,   26,   26,   39,
       39,   31,   32,  489,   26,   40,   40,   53,   53,   37,
       26,   26,   26,   26,   26,   26,   29,   29,   29,   29,

       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   29,   29,   29,   35,   35,   35,
       38,  487,   38,   58,   58,   35,   57,   57,   57,   59,
       59,   35,   35,   35,   35,   35,   35,   36,   36,   36,
       93,   93,   38,  106,  106,   36,   70,  482,   96,   68,
       96,   36,   36,   36,   36,   36,   36,   41,   41,   41,
       60,   60,   60,   68,   70,   41,  213,   60,   71,  111,

      111,   41,   41,   41,   41,   41,   41,   42,   42,   42,
       71,   97,  189,   71,  213,   42,   67,   97,  481,   67,
      189,   42,   42,   42,   42,   42,   42,   69,   67,   75,
       77,   69,   79,  114,  114,  480,   69,   75,   69,   77,
       80,   75,   79,   79,   80,   77,   88,  119,  119,  122,
      122,   80,  126,  126,  141,   88,   88,  150,  172,  172,
      172,  209,  200,  206,  479,  141,  141,  478,  150,  150,
      200,  206,  210,  210,  219,  214,  209,  214,  221,  475,
      214,  289,  230,  219,  219,  473,  289,  221,  221,  214,
      230,  317,  472,  471,  470,  317,  465,  464,  463,  457,

      141,  456,  454,  150,  181,  181,  181,  181,  181,  181,
      181,  181,  181,  181,  181,  181,  181,  453,  452,  451,
      181,  181,  181,  181,  181,  449,  442,  181,  441,  181,
      181,  439,  434,  429,  427,  422,  420,  419,  418,  417,
      415,  414,  411,  410,  407,  406,  402,  400,  399,  398,
      395,  394,  387,  382,  181,  192,  192,  192,  192,  192,
      192,  192,  192,  192,  192,  192,  192,  192,  377,  375,
      372,  192,  192,  192,  192,  192,  371,  370,  192,  369,
      192,  192,  367,  365,  364,  363,  362,  360,  359,  358,
      357,  356,  355,  353,  351,  349,  348,  347,  346,  344,

      343,  341,  338,  337,  331,  192,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  196,  196,  196,  328,
      326,  325,  196,  196,  196,  196,  196,  324,  321,  196,
      320,  196,  196,  318,  316,  315,  312,  310,  309,  308,
      307,  306,  305,  304,  303,  302,  301,  299,  298,  297,
      196,  296,  295,  294,  293,  292,  196,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      291,  290,  288,  197,  197,  197,  197,  197,  287,  286,
      197,  285,  197,  197,  284,  283,  282,  281,  279,  275,
      272,  270,  269,  268,  266,  265,  264,  263,  262,  261,

      260,  259,  258,  257,  256,  254,  253,  197,  274,  274,
      274,  274,  274,  274,  274,  274,  274,  274,  274,  274,
      274,  252,  246,  241,  274,  274,  274,  274,  274,  239,
      233,  274,  232,  274,  274,  231,  229,  228,  227,  223,
      217,  215,  212,  211,  208,  207,  205,  204,  203,  202,
      201,  199,  198,  195,  194,  193,  191,  190,  274,  276,
      276,  276,  276,  276,  276,  276,  276,  276,  276,  276,
      276,  276,  188,  187,  186,  276,  276,  276,  276,  276,
      185,  184,  276,  183,  276,  276,  182,  180,  179,  178,
      170,  164,  156,  137,  124,  121,  116,  113,  110,  107,

      103,   99,   98,   95,   90,   86,   83,   82,   81,  276,
      277,  277,  277,  277,  277,  277,  277,  277,  277,  277,
      277,  277,  277,   78,   76,   66,  277,  277,  277,  277,
      277,   65,   64,  277,   63,  277,  277,   62,   54,   52,
       50,   47,   45,   43,   10,    9,    2,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      277,  278,  278,  278,  278,  278,  278,  278,  278,  278,
      278,  278,  278,  278,    0,    0,    0,  278,  278,  278,
      278,  278,    0,    0,  278,    0,  278,  278,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  278,    0,    0,    0,
        0,  278,  280,  280,  280,  280,  280,  280,  280,  280,
      280,  280,  280,  280,  280,    0,    0,    0,  280,  280,
      280,  280,  280,    0,    0,  280,    0,  280,  280,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  280,  314,  314,  314,  314,  314,  314,  314,
      314,  314,  314,  314,  314,  314,    0,    0,    0,  314,
      314,  314,  314,  314,    0,    0,  314,    0,  314,  314,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  314,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,    0,    0,    0,
      319,  319,  319,  319,  319,    0,    0,  319,    0,  319,
      319,    0,    0,    0,    0,    0,    0,  319,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  319,  322,  322,  322,  322,  322,
      322,  322,  322,  322,  322,  322,  322,  322,    0,    0,
        0,  322,  322,  322,  322,  322,    0,    0,  322,    0,
      322,  322,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  322,  323,  323,  323,  323,
      323,  323,  323,  323,  323,  323,  323,  323,  323,    0,
        0,    0,  323,  323,  323,  323,  323,    0,    0,  323,
        0,  323,  323,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  323,  327,  327,  327,
      327,  327,  327,  327,  327,  327,  327,  327,  327,  327,
        0,    0,    0,  327,  327,  327,  327,  327,    0,    0,
      327,    0,  327,  327,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  327,  329,  329,
      329,  329,  329,  329,  329,  329,  329,  329,  329,  329,
      329,    0,    0,    0,  329,  329,  329,  329,  329,    0,
        0,  329,    0,  329,  329,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  329,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,    0,    0,    0,  330,  330,  330,  330,  330,
        0,    0,  330,    0,  330,  330,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  330,
      333,  333,  333,  333,  333,  333,  333,  333,  333,  333,
      333,  333,  333,    0,    0,    0,  333,  333,  333,  333,
      333,    0,    0,  333,    0,  333,  333,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      333,  340,  340,  340,  340,  340,  340,  340,  340,  340,
      340,  340,  340,  340,    0,    0,    0,  340,  340,  340,
      340,  340,    0,    0,  340,    0,  340,  340,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  340,  342,  342,  342,  342,  342,  342,  342,  342,
      342,  342,  342,  342,  342,    0,    0,    0,  342,  342,
      342,  342,  342,    0,    0,  342,    0,  342,  342,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  342,  345,  345,  345,  345,  345,  345,  345,
      345,  345,  345,  345,  345,  345,    0,    0,    0,  345,
      345,  345,  345,  345,    0,    0,  345,    0,  345,  345,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  345,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,    0,    0,    0,
      350,  350,  350,  350,  350,    0,    0,  350,    0,  350,
      350,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  350,  352,  352,  352,  352,  352,
      352,  352,  352,  352,  352,  352,  352,  352,    0,    0,
        0,  352,  352,  352,  352,  352,    0,    0,  352,    0,

      352,  352,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  352,  354,  354,  354,  354,
      354,  354,  354,  354,  354,  354,  354,  354,  354,    0,
        0,    0,  354,  354,  354,  354,  354,    0,    0,  354,
        0,  354,  354,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  354,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
        0,    0,    0,  373,  373,  373,  373,  373,    0,    0,

      373,    0,  373,  373,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  373,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,    0,    0,    0,  376,  376,  376,  376,  376,    0,
        0,  376,    0,  376,  376,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  376,  380,
      380,  380,  380,  380,  380,  380,  380,  380,  380,  380,
      380,  380,    0,    0,    0,  380,  380,  380,  380,  380,

        0,    0,  380,    0,  380,  380,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  380,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,    0,    0,    0,  381,  381,  381,  381,
      381,    0,    0,  381,    0,  381,  381,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      381,  384,  384,  384,  384,  384,  384,  384,  384,  384,
      384,  384,  384,  384,    0,    0,    0,  384,  384,  384,

      384,  384,    0,    0,  384,    0,  384,  384,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  384,  389,  389,  389,  389,  389,  389,  389,  389,
      389,  389,  389,  389,  389,    0,    0,    0,  389,  389,
      389,  389,  389,    0,    0,  389,    0,  389,  389,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  389,  390,  390,  390,  390,  390,  390,  390,
      390,  390,  390,  390,  390,  390,    0,    0,    0,  390,

      390,  390,  390,  390,    0,    0,  390,    0,  390,  390,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  390,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,    0,    0,    0,
      392,  392,  392,  392,  392,    0,    0,  392,    0,  392,
      392,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  392,  397,  397,  397,  397,  397,
      397,  397,  397,  397,  397,  397,  397,  397,    0,    0,

        0,  397,  397,  397,  397,  397,    0,    0,  397,    0,
      397,  397,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  397,  404,  404,  404,  404,
      404,  404,  404,  404,  404,  404,  404,  404,  404,    0,
        0,    0,  404,  404,  404,  404,  404,    0,    0,  404,
        0,  404,  404,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  404,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  404,  408,  408,  408,
      408,  408,  408,  408,  408,  408,  408,  408,  408,  408,

        0,    0,    0,  408,  408,  408,  408,  408,    0,    0,
      408,    0,  408,  408,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  408,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,    0,    0,    0,  409,  409,  409,  409,  409,    0,
        0,  409,    0,  409,  409,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  409,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,

      424,  424,    0,    0,    0,  424,  424,  424,  424,  424,
        0,    0,  424,    0,  424,  424,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  424,
      433,  433,  433,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,    0,    0,    0,  433,  433,  433,  433,
      433,    0,    0,  433,    0,  433,  433,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      433,  436,  436,  436,  436,  436,  436,  436,  436,  436,

      436,  436,  436,  436,    0,    0,    0,  436,  436,  436,
      436,  436,    0,    0,  436,    0,  436,  436,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  436,  437,  437,  437,  437,  437,  437,  437,  437,
      437,  437,  437,  437,  437,    0,    0,    0,  437,  437,
      437,  437,  437,    0,    0,  437,    0,  437,  437,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  437,  438,  438,  438,  438,  438,  438,  438,

      438,  438,  438,  438,  438,  438,    0,    0,    0,  438,
      438,  438,  438,  438,    0,    0,  438,    0,  438,  438,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  438,  443,  443,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  443,    0,    0,    0,
      443,  443,  443,  443,  443,    0,    0,  443,    0,  443,
      443,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  443,  446,  446,  446,  446,  446,

      446,  446,  446,  446,  446,  446,  446,  446,    0,    0,
        0,  446,  446,  446,  446,  446,    0,    0,  446,    0,
      446,  446,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  446,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,    0,
        0,    0,  450,  450,  450,  450,  450,    0,    0,  450,
        0,  450,  450,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,  450,  459,  459,  459,

      459,  459,  459,  459,  459,  459,  459,  459,  459,  459,
        0,    0,    0,  459,  459,  459,  459,  459,    0,    0,
      459,    0,  459,  459,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  459,  474,  474,
      474,  474,  474,  474,  474,  474,  474,  474,  474,  474,
      474,    0,    0,    0,  474,  474,  474,  474,  474,    0,
        0,  474,    0,  474,  474,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  474,  477,

      477,  477,  477,  477,  477,  477,  477,  477,  477,  477,
      477,  477,    0,    0,    0,  477,  477,  477,  477,  477,
        0,    0,  477,    0,  477,  477,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  477,
      483,  483,  483,  483,  483,  483,  483,  483,  483,  483,
      483,  483,  483,    0,    0,    0,  483,  483,  483,  483,
      483,    0,    0,  483,    0,  483,  483,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

      483,  485,  485,  485,  485,  485,  485,  485,  485,  485,
      485,  485,  485,  485,    0,    0,    0,  485,  485,  485,
      485,  485,    0,    0,  485,    0,  485,  485,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,  485,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,    0,    0,    0,  488,  488,
      488,  488,  488,    0,    0,  488,    0,  488,  488,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,  488,  490,  490,  490,  490,  490,  490,  490,
      490,  490,  490,  490,  490,  490,    0,    0,    0,  490,
      490,  490,  490,  490,    0,    0,  490,    0,  490,  490,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  490,  491,  491,  491,  491,  491,  491,
      491,  491,  491,  491,  491,  491,  491,    0,    0,    0,
      491,  491,  491,  491,  491,    0,    0,  491,    0,  491,
      491,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,  491,  494,  494,  494,  494,  494,
      494,  494,  494,  494,  494,  494,  494,  494,    0,    0,
        0,  494,  494,  494,  494,  494,    0,    0,  494,    0,
      494,  494,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  494,  496,  496,  496,  496,
      496,  496,  496,  496,  496,  496,  496,  496,  496,    0,
        0,    0,  496,  496,  496,  496,  496,    0,    0,  496,
        0,  496,  496,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  496,  502,  502,  502,
      502,  502,  502,  503,  503,  503,  503,  503,  503,  504,
      504,  504,  504,  504,  504,  505,  505,  505,  505,  505,
      505,  506,  506,  506,  506,  506,  506,  507,  507,  507,
      507,  507,  507,  508,  508,  508,  508,  508,  508,  509,
      509,  509,  509,  509,  509,  510,  510,  510,  510,  510,
      510,  511,  511,  511,  511,  511,  511,  512,  512,  512,
      512,  512,  512,  513,  513,  513,  513,  513,  513,  514,
      514,  515,  515,  515,  515,  515,  515,  516,  516,  516,
        0,  516,  516,  517,  517,  517,  517,  517,  517,  518,

      518,  519,    0,  519,  519,  519,  519,  520,  520,  521,
      521,  522,  522,  522,  522,  522,  522,  523,  523,  523,
      523,  523,  523,  524,    0,    0,  524,  524,  524,  525,
      525,  525,  525,  525,  525,  526,    0,  526,  526,  526,
      526,  527,    0,  527,  527,  527,  527,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501,  501,
      501,  501,  501,  501,  501,  501,  501,  501,  501

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int de_flex_debug;
int de_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *detext;
#line 1 "parser/marde.lex"
/* -*- c++ -*- Scanner for the Maria Debugger */
#define YY_NO_INPUT 1
#line 21 "parser/marde.lex"
# include <stdio.h>
# include <limits.h>
# include <string.h>
# include <assert.h>

# include "typedefs.h"
# include "marde.tab.h"

# include "StringBuffer.h"
# include "util.h"
# include "Printer.h"

  /** @file marde.lex
   * Lexical analyser for the query language
   */

  /* Copyright © 1999-2003 Marko Mäkelä (msmakela@tcs.hut.fi).

  This file is part of MARIA, a reachability analyzer and model checker
  for high-level Petri nets.

  MARIA is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.

  MARIA is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  The GNU General Public License is often shipped with GNU software, and
  is generally kept in a file called COPYING or LICENSE.  If you do not
  have a copy of the license, write to the Free Software Foundation,
  59 Temple Place, Suite 330, Boston, MA 02111 USA. */

  /** The printer object */
  extern class Printer thePrinter;
# include <list>
# include <stack>
  /** Stack of include files */
  struct input
  {
    /** name of the input file */
    class StringBuffer* name;
    /** input line number */
    unsigned lineno;
    /** number of unterminated preprocessor #if statements */
    unsigned condlevel;
    /** buffer state */
    YY_BUFFER_STATE bs;
  };
  static std::stack<struct input, std::list<struct input> > in;
  /** Current preprocessor condition directive */
  static enum { none, ifdef, ifndef, define, undef } currentDirective;
  /** preprocessor #if nesting level */
  static unsigned condlevel = 0;
  /** deepest #if nesting level where #else has an effect */
  static unsigned passlevel = 0;
  /** flag: pass tokens to the parser (instead of eating them up) */
  static bool pass = true;
  /** conditionally ignore the input */
# define I if (assert (!pass || condlevel == passlevel), !pass) break

  /** Dynamically growing string buffer */
  static class StringBuffer sbuf;
  /** @name String handling macros.  All of these use sbuf. */
  /*@{*/
# define CREAT memcpy (sbuf.create (deleng), detext, deleng + 1)
# define INITSTR sbuf.create (0)
# define EXTEND do {						\
    unsigned len = sbuf.getLength ();				\
    memcpy (sbuf.extend (deleng) + len, detext, deleng + 1);	\
  } while (0)
# define APPEND(c) do {				\
    unsigned len = sbuf.getLength ();		\
    (&((sbuf.extend (1))[len] = c))[1] = 0;	\
  } while (0)
# define COPY							\
  (strlen (delval.s = sbuf.copy ()) == sbuf.getLength ()) ||	\
  (deerror ("truncating name containing NUL chars"), 0)
  /*@}*/

  /** @name Start condition stack handling */
  /*@{*/
# define SC_FLUSH	yy_start_stack_ptr = 0, BEGIN (INITIAL)
# define SC_POP		yy_pop_state ()
# define SC_POP_B	do { SC_POP; yyless (0); } while (0)
# define SC_PUSH(s)	yy_push_state (s)
# define SC_SWITCH(s)	BEGIN (s)
# define SC_SWITCH_B(s)	do { yyless (0); SC_SWITCH (s); } while (0)
# define SC_CALL(s,r)	do { rt = r; SC_PUSH (ret); SC_PUSH (s); } while (0)
# define SC_USE(s,r)	do { SC_SWITCH (r); SC_PUSH (s); } while (0)
  /*@}*/

  /** initial source file name */
  extern const char* scriptname;
  /** Name of Petri Nets parsed from the command line */
  extern const char* scriptcommand;
  /** Petri Net model to be parsed from the command line */
  extern const char* scriptstring;
  /** Cursor to scriptstring */
  static const char* stringptr = NULL;

  /** flag: expecting a command keyword */
  extern bool command;

  /** Return a token
   * @param token	token to be returned
   */
# define RETURN(token)	return command = false, token
  /** Return a token as a command or as an identifier
   * @param token	token to be returned
   */
# define RETURNB(token)	return command ? token : (CREAT, COPY, NAME)
  /** Return a command or an identifier token, and clear the "command flag"
   * @param token	token to be returned
   */
# define RETURNC(token)							\
  return command ? (command = false, token) : (CREAT, COPY, NAME)
  /** source file line number */
  static unsigned lineno = 1;
  /** source file name */
  static class StringBuffer filename;

  /** Token to be returned to the parser */
  static int rt;
  /** Flag: input constant overflow */
  static bool overflow = false;
  /** Number of digits read in an octal or hexadecimal character constant */
  static unsigned digits = 0;
  /** Character constant being parsed in a string */
  static char character;

  /** Reset the lexical analyzer */
  void delexreset (void);

  /** warning flag (true=print warnings) */
  bool dewarnings = true;

  /**
   * display a message prefix at beginning of line
   * @return		number of characters written
   */
  unsigned demsg (void);

  /**
   * generic warning reporting function
   * @param s		warning message
   */
  void dewarn (const char* s);

  /**
   * generic parser error reporting function
   * @param s		error message
   */
  void deerror (const char* s);

  /** Open a script
   * @param name	name of the script
   * @return		a descriptor to the file, or NULL on error
   */
  extern FILE* openscript (const char* name);
  /** Switch files on EOF (return to the file that included the current file)
   * @return	true if there was a parent file
   */
  static bool popInclude (void);

  /** Check whether a preprocessor symbol is defined
   * @param sym		name of the symbol
   * @return		whether the symbol is defined
   */
  extern bool defined (const char* sym);
  /** Define a preprocessor symbol
   * @param sym		name of the symbol
   */
  extern void define_sym (const char* sym);
  /** Undefine a preprocessor symbol
   * @param sym		name of the symbol
   */
  extern void undef_sym (const char* sym);

  /** Advance to next buffer */
# define NEXTBUF do if (!popInclude ()) { SC_FLUSH; yyterminate (); } while (0)
  /** User-defined lexical analyser initialisation */
# define YY_USER_INIT NEXTBUF

  /** Read more input */
# define YY_INPUT(buf,result,max_size)					\
  if (!dein || dein == stdin) {						\
    if (!stringptr)							\
      result = 0;							\
    else if (*stringptr) {						\
      if ((result = strlen (stringptr)) > max_size)			\
	result = max_size;						\
      memcpy (buf, stringptr, result);					\
      stringptr += result;						\
    }									\
    else if (max_size >= 1)						\
      *buf = '\n', stringptr = NULL, result = 1;			\
    else								\
      result = 0;							\
  }									\
  else if (!(result = fread (buf, 1, max_size, dein)) && ferror (dein))	\
    deerror ("input error"), delexreset ()
/* Start conditions */
/* returning to the parser */

/* inside a comment */

/* parsing a preprocessor directive */

/* parsing a preprocessor directive, ignoring the rest of the line */

/* parsing a preprocessor directive "line" */

/* parsing a preprocessor directive "line", got line number */

/* parsing a preprocessor directive "line", got file name */

/* parsing a preprocessor directive "include" */

/* parsing a preprocessor directive "include", got file name */

/* parsing a preprocessor condition name */

/* parsing an octal constant */

/* parsing a hexadecimal constant */

/* parsing a decimal constant */

/* parsing a name */

/* parsing a character constant */

/* parsing an octal character constant */

/* parsing a hexadecimal character constant */

/* parsing a string constant */

/* parsing an octal character constant in a string */

/* parsing a hexadecimal character constant in a string */

#line 1614 "parser/lex.de.C"

#define INITIAL 0
#define ret 1
#define comment 2
#define pr 3
#define pr_ignore 4
#define pr_line 5
#define pr_line_number 6
#define pr_line_name 7
#define pr_incl 8
#define pr_incl_name 9
#define pr_cond 10
#define octal 11
#define hexadecimal 12
#define decimal 13
#define dename 14
#define dechar 15
#define dechar_oct 16
#define dechar_hex 17
#define destring 18
#define destring_oct 19
#define destring_hex 20

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int dewrap (void );
#else
extern int dewrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = 0;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( detext, deleng, 1, deout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( dein )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( dein ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, dein))==0 && ferror(dein)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(dein); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int delex (void);

#define YY_DECL int delex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after detext and deleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( deleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(detext[deleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 276 "parser/marde.lex"


#line 1797 "parser/lex.de.C"

	if ( (yy_init) )
		{
		(yy_init) = 0;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! dein )
			dein = stdin;

		if ( ! deout )
			deout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			deensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				de_create_buffer(dein,YY_BUF_SIZE );
		}

		de_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of detext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 502 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 501 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 278 "parser/marde.lex"
{ SC_POP_B; I; if (rt == NAME) COPY; RETURN (rt); }
	YY_BREAK
case YY_STATE_EOF(ret):
#line 279 "parser/marde.lex"
{ SC_POP; NEXTBUF; I; if (rt == NAME) COPY; RETURN (rt); }
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 282 "parser/marde.lex"

	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 283 "parser/marde.lex"
lineno++;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 284 "parser/marde.lex"

	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 285 "parser/marde.lex"
lineno++;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 286 "parser/marde.lex"
SC_POP;
	YY_BREAK
case YY_STATE_EOF(comment):
#line 287 "parser/marde.lex"
{ deerror ("EOF in comment"); SC_POP; NEXTBUF; }
	YY_BREAK


case 7:
YY_RULE_SETUP
#line 291 "parser/marde.lex"

	YY_BREAK
case 8:
YY_RULE_SETUP
#line 292 "parser/marde.lex"

	YY_BREAK
case 9:
YY_RULE_SETUP
#line 293 "parser/marde.lex"
SC_PUSH (comment);
	YY_BREAK
case YY_STATE_EOF(pr):
case YY_STATE_EOF(pr_line):
case YY_STATE_EOF(pr_line_number):
case YY_STATE_EOF(pr_line_name):
case YY_STATE_EOF(pr_incl):
case YY_STATE_EOF(pr_incl_name):
case YY_STATE_EOF(pr_cond):
#line 294 "parser/marde.lex"
{ SC_POP; NEXTBUF; }
	YY_BREAK


case 10:
YY_RULE_SETUP
#line 298 "parser/marde.lex"
SC_SWITCH (pr_incl);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 299 "parser/marde.lex"
SC_SWITCH (pr_line);
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 300 "parser/marde.lex"
{
    if (!condlevel)
      deerror ("#else without #if");
    else if (pass)
      assert (passlevel == condlevel), pass = false, passlevel--;
    else if (passlevel + 1 == condlevel)
      pass = true, passlevel++;
    else
      assert (passlevel < condlevel);
    currentDirective = none; SC_SWITCH (pr_cond);
  }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 311 "parser/marde.lex"
{
    if (!condlevel)
      deerror ("#endif without #if");
    else if (passlevel >= --condlevel)
      pass = true, passlevel = condlevel;
    currentDirective = none; SC_SWITCH (pr_cond);
  }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 319 "parser/marde.lex"
{ currentDirective = ifdef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 320 "parser/marde.lex"
{ currentDirective = ifndef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 321 "parser/marde.lex"
{ currentDirective = define; SC_SWITCH (pr_cond); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 322 "parser/marde.lex"
{ currentDirective = undef; SC_SWITCH (pr_cond); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 324 "parser/marde.lex"
{
    deerror ("unknown preprocessor directive");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 328 "parser/marde.lex"
{
    SC_SWITCH (pr_ignore); /* #! interpreter command */
  }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 331 "parser/marde.lex"
{
    deerror ("error in preprocessor directive"); SC_SWITCH (pr_ignore);
  }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 334 "parser/marde.lex"
{
    deerror ("expected a preprocessor directive"); SC_POP; lineno++;
  }
	YY_BREAK


case 22:
YY_RULE_SETUP
#line 340 "parser/marde.lex"
SC_POP;
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 341 "parser/marde.lex"
{ SC_POP; lineno++; }
	YY_BREAK
case YY_STATE_EOF(pr_ignore):
#line 342 "parser/marde.lex"
{ SC_POP; NEXTBUF; }
	YY_BREAK


case 24:
YY_RULE_SETUP
#line 346 "parser/marde.lex"
{
    delval.i = 0, overflow = false;
    SC_USE (hexadecimal, pr_line_number);
  }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 350 "parser/marde.lex"
{
    delval.i = 0, overflow = false;
    SC_USE (octal, pr_line_number);
  }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 354 "parser/marde.lex"
{
    delval.i = *detext - '0', overflow = false;
    SC_USE (decimal, pr_line_number);
  }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 358 "parser/marde.lex"
{ INITSTR; SC_USE (destring, pr_line_name); }
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 359 "parser/marde.lex"
{ lineno++; SC_POP; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 360 "parser/marde.lex"
{
    deerror ("error in preprocessor directive #line");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 366 "parser/marde.lex"
{
  SC_SWITCH_B (pr_line);
  lineno = delval.i - 1;
}
	YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
#line 371 "parser/marde.lex"
{ SC_SWITCH_B (pr_line); filename = sbuf; }
	YY_BREAK

case 32:
YY_RULE_SETUP
#line 374 "parser/marde.lex"
{ INITSTR; SC_USE (destring, pr_incl_name); }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 375 "parser/marde.lex"
{
    deerror ("unexceptedly terminated preprocessor directive #include");
    lineno++; SC_POP;
  }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 379 "parser/marde.lex"
{
    deerror ("error in preprocessor directive #include");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 385 "parser/marde.lex"
{
  SC_POP_B; I;
  if (FILE* f = openscript (sbuf.getString ())) {
    struct input is = {
      new class StringBuffer (filename), lineno, condlevel, YY_CURRENT_BUFFER
    };
    in.push (is);
    filename = sbuf;
    lineno = 1;
    de_switch_to_buffer (de_create_buffer (f, YY_BUF_SIZE));
  }
  else {
    perror (sbuf.getString ());
    deerror ("could not open include file");
  }
}
	YY_BREAK

case 36:
YY_RULE_SETUP
#line 403 "parser/marde.lex"
{
    switch (currentDirective) {
    case none:
      deerror ("error in preprocessor directive"); SC_SWITCH (pr_ignore);
      break;
    case ifdef:
      condlevel++;
      if (pass) {
	if (!defined (detext))
	  pass = false;
	else
	  passlevel = condlevel;
      }
      break;
    case ifndef:
      condlevel++;
      if (pass) {
	if (defined (detext))
	  pass = false;
	else
	  passlevel = condlevel;
      }
      break;
    case define:
      if (pass) define_sym (detext);
      break;
    case undef:
      if (pass) undef_sym (detext);
      break;
    }
    currentDirective = none;
  }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 436 "parser/marde.lex"
{
    if (currentDirective != none)
      deerror ("missing condition name");
    lineno++; SC_POP;
  }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 442 "parser/marde.lex"
{
    deerror ("error in preprocessor condition directive");
    SC_SWITCH (pr_ignore);
  }
	YY_BREAK

case 39:
YY_RULE_SETUP
#line 448 "parser/marde.lex"

	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 449 "parser/marde.lex"
lineno++;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 450 "parser/marde.lex"
SC_PUSH (comment);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 451 "parser/marde.lex"

	YY_BREAK
case 43:
YY_RULE_SETUP
#line 452 "parser/marde.lex"
SC_PUSH (pr);
	YY_BREAK
case 44:
/* rule 44 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 454 "parser/marde.lex"
{ I; RETURN (UNION); }
	YY_BREAK
case 45:
/* rule 45 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 455 "parser/marde.lex"
{ I; RETURN (IS); }
	YY_BREAK
case 46:
/* rule 46 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 456 "parser/marde.lex"
{ I; RETURN (UNTIL); }
	YY_BREAK
case 47:
/* rule 47 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 7;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 457 "parser/marde.lex"
{ I; RETURN (RELEASE); }
	YY_BREAK
case 48:
/* rule 48 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 458 "parser/marde.lex"
{ I; RETURN (SUBSET); }
	YY_BREAK
case 49:
/* rule 49 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 459 "parser/marde.lex"
{ I; RETURN (INTERSECT); }
	YY_BREAK
case 50:
/* rule 50 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 460 "parser/marde.lex"
{ I; RETURN (EQUALS); }
	YY_BREAK
case 51:
/* rule 51 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 461 "parser/marde.lex"
{ I; RETURN (MINUS); }
	YY_BREAK
case 52:
/* rule 52 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 462 "parser/marde.lex"
{ I; RETURN (ATOM_); }
	YY_BREAK
case 53:
/* rule 53 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 463 "parser/marde.lex"
{ I; RETURN (EMPTY); }
	YY_BREAK
case 54:
/* rule 54 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 464 "parser/marde.lex"
{ I; RETURN (MAP); }
	YY_BREAK
case 55:
/* rule 55 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 466 "parser/marde.lex"
{ I; RETURN (PLACE); }
	YY_BREAK
case 56:
/* rule 56 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 467 "parser/marde.lex"
{ I; RETURN (TRANS); }
	YY_BREAK
case 57:
/* rule 57 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 468 "parser/marde.lex"
{ I; RETURN (IN_); }
	YY_BREAK
case 58:
/* rule 58 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 469 "parser/marde.lex"
{ I; RETURN (OUT_); }
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 470 "parser/marde.lex"
{ I; RETURN (GATE); }
	YY_BREAK
case 60:
/* rule 60 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 471 "parser/marde.lex"
{ I; RETURN (TRUE_); }
	YY_BREAK
case 61:
/* rule 61 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 472 "parser/marde.lex"
{ I; RETURN (FALSE_); }
	YY_BREAK
case 62:
/* rule 62 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 473 "parser/marde.lex"
{ I; RETURN (UNDEFINED); }
	YY_BREAK
case 63:
/* rule 63 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 474 "parser/marde.lex"
{ I; RETURN (FATAL); }
	YY_BREAK
case 64:
/* rule 64 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 11;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 476 "parser/marde.lex"
{ I; RETURN (CARDINALITY); }
	YY_BREAK
case 65:
/* rule 65 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 477 "parser/marde.lex"
{ I; RETURN (MIN_); }
	YY_BREAK
case 66:
/* rule 66 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 478 "parser/marde.lex"
{ I; RETURN (MAX_); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 480 "parser/marde.lex"
{ I; RETURN (IMPL); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 481 "parser/marde.lex"
{ I; RETURN (XOR); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 482 "parser/marde.lex"
{ I; RETURN (EQUIV); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 483 "parser/marde.lex"
{ I; RETURN (OR); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 484 "parser/marde.lex"
{ I; RETURN (AND); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 485 "parser/marde.lex"
{ I; RETURN (FINALLY); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 486 "parser/marde.lex"
{ I; RETURN (GLOBALLY); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 487 "parser/marde.lex"
{ I; RETURN (NEXT); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 489 "parser/marde.lex"
{ I; RETURN (EQ); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 490 "parser/marde.lex"
{ I; RETURN (NE); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 491 "parser/marde.lex"
{ I; RETURN (GE); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 492 "parser/marde.lex"
{ I; RETURN (LE); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 493 "parser/marde.lex"
{ I; RETURN (ROL); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 494 "parser/marde.lex"
{ I; RETURN (ROR); }
	YY_BREAK
case 81:
/* rule 81 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 496 "parser/marde.lex"
{ I; RETURNC (MODEL); }
	YY_BREAK
case 82:
/* rule 82 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 497 "parser/marde.lex"
{ I; RETURNC (GRAPH); }
	YY_BREAK
case 83:
/* rule 83 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 498 "parser/marde.lex"
{ I; RETURNC (LSTS); }
	YY_BREAK
case 84:
/* rule 84 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 499 "parser/marde.lex"
{ I; RETURNC (UNFOLD); }
	YY_BREAK
case 85:
/* rule 85 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 7;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 500 "parser/marde.lex"
{ I; RETURNC (BREADTH); }
	YY_BREAK
case 86:
/* rule 86 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 501 "parser/marde.lex"
{ I; RETURNC (DEPTH); }
	YY_BREAK
case 87:
/* rule 87 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 502 "parser/marde.lex"
{ I; RETURNC (STRONG); }
	YY_BREAK
case 88:
/* rule 88 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 503 "parser/marde.lex"
{ I; RETURNC (PATH); }
	YY_BREAK
case 89:
/* rule 89 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 504 "parser/marde.lex"
{ I; RETURNC (TERMINAL); }
	YY_BREAK
case 90:
/* rule 90 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 10;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 505 "parser/marde.lex"
{ I; RETURNC (COMPONENTS); }
	YY_BREAK
case 91:
/* rule 91 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 506 "parser/marde.lex"
{ I; RETURNC (CD); }
	YY_BREAK
case 92:
/* rule 92 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 10;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 507 "parser/marde.lex"
{ I; RETURNC (TRANSLATOR); }
	YY_BREAK
case 93:
/* rule 93 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 10;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 508 "parser/marde.lex"
{ I; RETURNC (COMPILEDIR); }
	YY_BREAK
case 94:
/* rule 94 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 509 "parser/marde.lex"
{ I; RETURNB (VISUAL); }
	YY_BREAK
case 95:
/* rule 95 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 510 "parser/marde.lex"
{ I; RETURNC (DUMP); }
	YY_BREAK
case 96:
/* rule 96 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 9;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 511 "parser/marde.lex"
{ I; RETURNC (DUMPGRAPH); }
	YY_BREAK
case 97:
/* rule 97 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 512 "parser/marde.lex"
{ I; RETURNC (EVAL); }
	YY_BREAK
case 98:
/* rule 98 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 513 "parser/marde.lex"
{ I; RETURNC (HIDE); }
	YY_BREAK
case 99:
/* rule 99 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 514 "parser/marde.lex"
{ I; RETURNC (SUBNET); }
	YY_BREAK
case 100:
/* rule 100 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 515 "parser/marde.lex"
{ I; RETURNC (SHOW); }
	YY_BREAK
case 101:
/* rule 101 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 516 "parser/marde.lex"
{ I; RETURNC (SUCC); }
	YY_BREAK
case 102:
/* rule 102 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 517 "parser/marde.lex"
{ I; RETURNC (PRED); }
	YY_BREAK
case 103:
/* rule 103 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 518 "parser/marde.lex"
{ I; RETURNC (GO); }
	YY_BREAK
case 104:
/* rule 104 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 519 "parser/marde.lex"
{ I; RETURNC (STATS); }
	YY_BREAK
case 105:
/* rule 105 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 520 "parser/marde.lex"
{ I; RETURNC (TIME); }
	YY_BREAK
case 106:
/* rule 106 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 521 "parser/marde.lex"
{ I; RETURNC (HELP); }
	YY_BREAK
case 107:
/* rule 107 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 522 "parser/marde.lex"
{ I; RETURNC (LOG); }
	YY_BREAK
case 108:
/* rule 108 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 523 "parser/marde.lex"
{ I; RETURNC (FUNCTION); }
	YY_BREAK
case 109:
/* rule 109 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 524 "parser/marde.lex"
{ I; RETURNC (PROMPT); }
	YY_BREAK
case 110:
/* rule 110 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 4;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 525 "parser/marde.lex"
{ I; RETURNC (EXIT); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 527 "parser/marde.lex"
{
  delval.i = 0, overflow = false;
  SC_CALL (hexadecimal,
	   *detext == '@' ? (detext[1] == '@' ? COMP : STATE) : NUMBER);
}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 532 "parser/marde.lex"
{
  delval.i = 0, overflow = false;
  SC_CALL (octal,
	   *detext == '@' ? (detext[1] == '@' ? COMP : STATE) : NUMBER);
}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 537 "parser/marde.lex"
{
  delval.i = *detext - '0', overflow = false; SC_CALL (decimal, NUMBER);
}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 540 "parser/marde.lex"
{
  delval.i = detext[1] - '0', overflow = false; SC_CALL (decimal, STATE);
}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 543 "parser/marde.lex"
{
  delval.i = detext[2] - '0', overflow = false; SC_CALL (decimal, COMP);
}
	YY_BREAK

case 116:
YY_RULE_SETUP
#line 548 "parser/marde.lex"
{
    if (overflow);
    else if (delval.i > CARD_T_MAX >> 4)
      deerror ("hexadecimal constant too large"), overflow = true;
    else
      (delval.i <<= 4) |= *detext - '0';
  }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 555 "parser/marde.lex"
{
    if (overflow);
    else if (delval.i > CARD_T_MAX >> 4)
      deerror ("hexadecimal constant too large"), overflow = true;
    else
      (delval.i <<= 4) |= *detext - 'A' + 0x0A;
  }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 562 "parser/marde.lex"
{
    if (overflow);
    else if (delval.i > CARD_T_MAX >> 4)
      deerror ("hexadecimal constant too large"), overflow = true;
    else
      (delval.i <<= 4) |= *detext - 'a' + 0x0A;
  }
	YY_BREAK

case 119:
YY_RULE_SETUP
#line 571 "parser/marde.lex"
{
  if (overflow);
  else if (delval.i > CARD_T_MAX >> 3)
    deerror ("octal constant too large"), overflow = true;
  else
    (delval.i <<= 3) |= *detext - '0';
}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 579 "parser/marde.lex"
{
  if (!overflow) {
    card_t v = delval.i * 10 + (*detext - '0');
    if (v / 10 != delval.i)
      deerror ("decimal constant too large"), overflow = true;
    else
      delval.i = v;
  }
}
	YY_BREAK

case 121:
YY_RULE_SETUP
#line 590 "parser/marde.lex"
{
    deerror ("improperly terminated numeric constant");
    yyless (0); SC_POP;
  }
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 594 "parser/marde.lex"
{
    yyless (0); SC_POP;
  }
	YY_BREAK
case YY_STATE_EOF(hexadecimal):
case YY_STATE_EOF(octal):
case YY_STATE_EOF(decimal):
#line 597 "parser/marde.lex"
{
    SC_POP; NEXTBUF;
  }
	YY_BREAK

case 123:
YY_RULE_SETUP
#line 602 "parser/marde.lex"
{ CREAT; SC_PUSH (dename); }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 603 "parser/marde.lex"
{ INITSTR; APPEND (detext[1]); SC_PUSH (dename); }
	YY_BREAK

case 125:
/* rule 125 can match eol */
YY_RULE_SETUP
#line 606 "parser/marde.lex"
lineno++;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 607 "parser/marde.lex"
APPEND (detext[1]);
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 608 "parser/marde.lex"
EXTEND;
	YY_BREAK
case 128:
/* rule 128 can match eol */
YY_RULE_SETUP
#line 609 "parser/marde.lex"
{ SC_POP_B; I; COPY; RETURN (NAME); }
	YY_BREAK

case 129:
YY_RULE_SETUP
#line 612 "parser/marde.lex"
{ overflow = false; SC_PUSH (dechar); }
	YY_BREAK

case 130:
YY_RULE_SETUP
#line 615 "parser/marde.lex"
{
    if (!overflow) {
      deerror ("null char constant");
      delval.c = 0;
    }
    SC_POP; I; RETURN (CHARACTER);
  }
	YY_BREAK
case 131:
/* rule 131 can match eol */
YY_RULE_SETUP
#line 622 "parser/marde.lex"
lineno++;
	YY_BREAK
case 132:
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 623 "parser/marde.lex"
{
    if (!overflow) {
      delval.c = 0, digits = 0, overflow = true; SC_SWITCH (dechar_oct);
    }
    else
      deerror ("char constant too large, ignoring `\\'");
  }
	YY_BREAK
case 133:
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 630 "parser/marde.lex"
{
    if (!overflow) {
      delval.c = 0, digits = 0, overflow = true; SC_SWITCH (dechar_hex);
    }
    else
      deerror ("char constant too large, ignoring `\\x'");
  }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 637 "parser/marde.lex"
{
    if (!overflow) {
      overflow = true;
      switch (detext[1]) {
      case 'a': delval.c = '\a'; break;
      case 'b': delval.c = '\b'; break;
      case 't': delval.c = '\t'; break;
      case 'n': delval.c = '\n'; break;
      case 'v': delval.c = '\v'; break;
      case 'f': delval.c = '\f'; break;
      case 'r': delval.c = '\r'; break;
      default:
	delval.c = detext[1];
      }
    }
    else
      deerror ("char constant too large");
  }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 655 "parser/marde.lex"
{
    if (!overflow) {
      overflow = true;
      delval.c = *detext;
    }
    else
      deerror ("char constant too large");
  }
	YY_BREAK
case 136:
/* rule 136 can match eol */
YY_RULE_SETUP
#line 663 "parser/marde.lex"
{
    lineno++;
    deerror ("unterminated char constant");
    if (!overflow)
      delval.c = 0;
    SC_POP; I; RETURN (CHARACTER);
  }
	YY_BREAK

case 137:
YY_RULE_SETUP
#line 672 "parser/marde.lex"
{
  (delval.c <<= 3) |= *detext - '0';
  if (++digits >= 3 || (delval.c >> (CHAR_T_BIT - 3)))
    SC_SWITCH (dechar);
}
	YY_BREAK

case 138:
YY_RULE_SETUP
#line 679 "parser/marde.lex"
{
    (delval.c <<= 4) |= *detext - '0';
    if (++digits >= 2)
      SC_SWITCH (dechar);
  }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 684 "parser/marde.lex"
{
    (delval.c <<= 4) |= *detext - 'a' + 0x0a;
    if (++digits >= 2)
      SC_SWITCH (dechar);
  }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 689 "parser/marde.lex"
{
    (delval.c <<= 4) |= *detext - 'A' + 0x0a;
    if (++digits >= 2)
      SC_SWITCH (dechar);
  }
	YY_BREAK


case 141:
/* rule 141 can match eol */
YY_RULE_SETUP
#line 697 "parser/marde.lex"
SC_SWITCH_B (dechar);
	YY_BREAK

case YY_STATE_EOF(dechar):
case YY_STATE_EOF(dechar_oct):
case YY_STATE_EOF(dechar_hex):
#line 700 "parser/marde.lex"
{
  deerror ("EOF in char constant"); SC_POP; NEXTBUF;
}
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 704 "parser/marde.lex"
{ INITSTR; SC_CALL (destring, NAME); }
	YY_BREAK

case 143:
YY_RULE_SETUP
#line 707 "parser/marde.lex"
SC_POP;
	YY_BREAK
case 144:
/* rule 144 can match eol */
YY_RULE_SETUP
#line 708 "parser/marde.lex"
lineno++;
	YY_BREAK
case 145:
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 709 "parser/marde.lex"
{
    character = 0, digits = 0; SC_SWITCH (destring_oct);
  }
	YY_BREAK
case 146:
*yy_cp = (yy_hold_char); /* undo effects of setting up detext */
(yy_c_buf_p) = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up detext again */
YY_RULE_SETUP
#line 712 "parser/marde.lex"
{
    character = 0, digits = 0; SC_SWITCH (destring_hex);
  }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 715 "parser/marde.lex"

	YY_BREAK
case 148:
YY_RULE_SETUP
#line 716 "parser/marde.lex"
{
    switch (detext[1]) {
    case 'a': APPEND ('\a'); break;
    case 'b': APPEND ('\b'); break;
    case 't': APPEND ('\t'); break;
    case 'n': APPEND ('\n'); break;
    case 'v': APPEND ('\v'); break;
    case 'f': APPEND ('\f'); break;
    case 'r': APPEND ('\r'); break;
    default:
      APPEND (detext[1]);
    }
  }
	YY_BREAK
case 149:
/* rule 149 can match eol */
YY_RULE_SETUP
#line 729 "parser/marde.lex"
{ EXTEND; lineno++; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 730 "parser/marde.lex"
EXTEND;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 731 "parser/marde.lex"
{
    deerror ("string constant terminated by `\\'"); EXTEND; SC_POP;
  }
	YY_BREAK
case YY_STATE_EOF(destring):
#line 734 "parser/marde.lex"
{
    deerror ("EOF in string constant"); SC_POP; NEXTBUF;
  }
	YY_BREAK

case 152:
YY_RULE_SETUP
#line 739 "parser/marde.lex"
{
  (character <<= 3) |= *detext - '0';
  if (++digits >= 3 || (character >> (CHAR_BIT - 3))) {
    APPEND (character);
    SC_SWITCH (destring);
  }
}
	YY_BREAK

case 153:
YY_RULE_SETUP
#line 748 "parser/marde.lex"
{
    (character <<= 4) |= *detext - '0';
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (destring);
    }
  }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 755 "parser/marde.lex"
{
    (character <<= 4) |= *detext - 'a' + 0x0a;
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (destring);
    }
  }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 762 "parser/marde.lex"
{
    (character <<= 4) |= *detext - 'A' + 0x0a;
    if (++digits >= 2) {
      APPEND (character);
      SC_SWITCH (destring);
    }
  }
	YY_BREAK


case 156:
/* rule 156 can match eol */
YY_RULE_SETUP
#line 772 "parser/marde.lex"
{ APPEND (character); SC_SWITCH_B (destring); }
	YY_BREAK
case YY_STATE_EOF(destring_oct):
case YY_STATE_EOF(destring_hex):
#line 773 "parser/marde.lex"
{
    APPEND (character); SC_POP;
    deerror ("EOF at escaped character in string constant"); NEXTBUF;
  }
	YY_BREAK

case 157:
YY_RULE_SETUP
#line 779 "parser/marde.lex"
{ I; return *detext; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 780 "parser/marde.lex"
{ I; RETURN (*detext); }
	YY_BREAK
case 159:
/* rule 159 can match eol */
YY_RULE_SETUP
#line 781 "parser/marde.lex"
lineno++;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 782 "parser/marde.lex"
deerror ("unknown character");
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 784 "parser/marde.lex"
NEXTBUF;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 786 "parser/marde.lex"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3272 "parser/lex.de.C"
case YY_STATE_EOF(dename):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed dein at a new source and called
			 * delex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = dein;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( dewrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * detext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of delex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					derealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			derestart(dein  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 502 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 502 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 501);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					derestart(dein );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( dewrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve detext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void derestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        deensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            de_create_buffer(dein,YY_BUF_SIZE );
	}

	de_init_buffer(YY_CURRENT_BUFFER,input_file );
	de_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void de_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		depop_buffer_state();
	 *		depush_buffer_state(new_buffer);
     */
	deensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	de_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (dewrap()) processing, but the only time this flag
	 * is looked at is after dewrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void de_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	dein = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE de_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) dealloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in de_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) dealloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in de_create_buffer()" );

	b->yy_is_our_buffer = 1;

	de_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with de_create_buffer()
 * 
 */
    void de_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		defree((void *) b->yy_ch_buf  );

	defree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a derestart() or at EOF.
 */
    static void de_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	de_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then de_init_buffer was _probably_
     * called from derestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void de_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		de_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void depush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	deensure_buffer_stack();

	/* This block is copied from de_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from de_switch_to_buffer. */
	de_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void depop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	de_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		de_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void deensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)dealloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)derealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) dealloc(new_size  );

		else
			(yy_start_stack) = (int *) derealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR(
			"out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up detext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		detext[deleng] = (yy_hold_char); \
		(yy_c_buf_p) = detext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		deleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int deget_lineno  (void)
{
        
    return delineno;
}

/** Get the input stream.
 * 
 */
FILE *deget_in  (void)
{
        return dein;
}

/** Get the output stream.
 * 
 */
FILE *deget_out  (void)
{
        return deout;
}

/** Get the length of the current token.
 * 
 */
int deget_leng  (void)
{
        return deleng;
}

/** Get the current token.
 * 
 */

char *deget_text  (void)
{
        return detext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void deset_lineno (int  line_number )
{
    
    delineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see de_switch_to_buffer
 */
void deset_in (FILE *  in_str )
{
        dein = in_str ;
}

void deset_out (FILE *  out_str )
{
        deout = out_str ;
}

int deget_debug  (void)
{
        return de_flex_debug;
}

void deset_debug (int  bdebug )
{
        de_flex_debug = bdebug ;
}

/* delex_destroy is for both reentrant and non-reentrant scanners. */
int delex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		de_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		depop_buffer_state();
	}

	/* Destroy the stack itself. */
	defree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        defree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
    	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
    	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *dealloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *derealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void defree (void * ptr )
{
	free( (char *) ptr );	/* see derealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#undef YY_NEW_FILE
#undef YY_FLUSH_BUFFER
#undef yy_set_bol
#undef yy_new_buffer
#undef yy_set_interactive
#undef yytext_ptr
#undef YY_DO_BEFORE_ACTION

#ifdef YY_DECL_IS_OURS
#undef YY_DECL_IS_OURS
#undef YY_DECL
#endif
#line 786 "parser/marde.lex"



static const char* lastscriptname;
static const char* lastscriptstring;

void
delexreset (void)
{
  lineno = 1;
  filename.create (0);
  lastscriptname = 0;
  stringptr = lastscriptstring = 0;
  overflow = false;
  condlevel = passlevel = 0;
  pass = true;
  thePrinter.setBOL (&demsg);
  SC_FLUSH;
  while (!in.empty ())
    popInclude ();
  yy_init = 1;
  struct yy_buffer_state* b = YY_CURRENT_BUFFER;
  de_delete_buffer (b);
  if (yy_start_stack) {
    free (yy_start_stack);
    yy_start_stack = 0;
    yy_start_stack_depth = 0;
  }
}

unsigned
demsg (void)
{
  return fprintf (stderr, "%s:%u:", filename.getString (), lineno);
}

void
dewarn (const char* s)
{
  if (dewarnings)
    fprintf (stderr, "%s:%u:Warning:%s\n", filename.getString (), lineno, s);
}

void
deerror (const char* s)
{
  if (!strcmp (s, "parse error"))
    command = true;
  fprintf (stderr, "%s:%u:%s\n", filename.getString (), lineno, s);
}

static bool
popInclude (void)
{
  {
    size_t oldcondlevel = in.empty () ? 0 : in.top ().condlevel;

    if (oldcondlevel < condlevel) {
      deerror ("too many #if statements");
    }
    else if (oldcondlevel > condlevel) {
      deerror ("too many #endif statements");
    }
  }

  if (dein && dein != stdin) fclose (dein);

  if (in.empty ()) {
    derestart (0);
    if (lastscriptname == scriptname && lastscriptstring == scriptstring) {
      filename = scriptname;
      return false;
    }
    else if (filename = lastscriptname = scriptname,
	     scriptname == scriptcommand) {
      if (lastscriptstring == scriptstring) {
	yy_init = 1;
	return false;
      }
      stringptr = lastscriptstring = scriptstring;
      return true;
    }
    else if (!(dein = openscript (lastscriptname))) {
      perror (lastscriptname);
      yy_init = 1;
      return false;
    }
    else {
      lineno = 1;
      derestart (dein);
      return true;
    }
  }
  else {
    filename = *in.top ().name;
    lineno = in.top ().lineno;
    delete in.top ().name;
    de_delete_buffer (YY_CURRENT_BUFFER);
    de_switch_to_buffer (in.top ().bs);
    in.pop ();
    return true;
  }
}

